==> larus_board-1.1.2.zip: larus_board-1.1.2/lb_private/lang/en/acpcfg.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'cfg_explain_auth_activate_limit'=>'How long can new accounts be unactivated until purged? Value: <u>time</u>.',
'cfg_explain_auth_bind_agent'=>'On login the current user agent is stored. If <u>enabled</u> the login gets invalid, as it changes during the session.',
'cfg_explain_auth_bind_ip'=>'On login the current IP-Address is stored. If <u>enabled</u> the login gets invalid, as it changes during the session.',
'cfg_explain_auth_max_faillogin'=>'How many fail logins are allowed until the possiblity of login is suspended for a few minutes?',
'cfg_explain_auth_max_lifetime'=>'How long does a login session remain valid? Value: <u>time</u>.',
'cfg_explain_auth_use_reauth'=>'Does an invalid login session may perform limited reauthentication attempts by giving its password?',
'cfg_explain_auth_use_tan'=>'Should changes submitted on forms be secured by a transaction number (TAN)?',
'cfg_explain_cache_acl'=>'Enable caching of access control rules?',
'cfg_explain_cache_config'=>'Enable caching of configuration?',
'cfg_explain_cache_main'=>'Enable caching of common data?',
'cfg_explain_cache_rss'=>'Enable caching of parsed RSS feeds?',
'cfg_explain_cache_topic'=>'Enable caching of topic data?',
'cfg_explain_cache_tpl'=>'Enable caching of compiled templates?',
'cfg_explain_cache_user'=>'Enable caching of user account data?',
'cfg_explain_cookie_autologin'=>'Name of the cookie for auto login.',
'cfg_explain_cookie_domain'=>'You can limit the domain where the cookies are allowed. Usually this is your full qualified domain name ("www.example.com").',
'cfg_explain_cookie_path'=>'You can limit them to specific paths on your domain name. Most compatible is "/".',
'cfg_explain_cookie_read_tracker'=>'Name of the cookie for "Last-Read-Post-Timestamp".',
'cfg_explain_cookie_session'=>'Name of the cookie for login session.',
'cfg_explain_cookie_ssl_only'=>'If <u>enabled</u>, the cookies are only transported over a secured (SSL) connection.',
'cfg_explain_filter_enable'=>'If you want to filter all postings for unwanted, please <u>enable</u> it here.',
'cfg_explain_filter_max_age_ip4'=>'How long are entries on IP-Addresses remain valid?',
'cfg_explain_filter_max_age_msg'=>'How long are entries on Postings remain valid?',
'cfg_explain_filter_max_age_uid'=>'How long are entries on User Accounts remain valid?',
'cfg_explain_filter_remote_proxy'=>'If any remote connections to other servers have to be done by a proxy, you should define it here. In most cases this field can be left blank.',
'cfg_explain_filter_sink_dnsbl_server'=>'Which nameservers should be queried for blacklisted addresses? You can set multiple by seperating them with a comma.',
'cfg_explain_filter_sink_local_class'=>'Any filter running on the local system can be included here. You should really consult our documentation for setup.',
'cfg_explain_filter_sink_local_param'=>'Any parameters to the filter class can be passed here.',
'cfg_explain_filter_size'=>'How many entries should be stored in our local database?',
'cfg_explain_filter_spam_action'=>'What should be done with marked postings? You can <u>accept</u> these anyway, <u>mark</u> makes them hidden or <u>reject</u> directly.',
'cfg_explain_filter_threshold'=>'When the local filter returns a score value, you can define here a threshold. Higher will be considered unwanted.',
'cfg_explain_help_class'=>'What type of support would you like to offer? <u>direct</u> means by submitting a topic and <u>mail</u> by e-mail.',
'cfg_explain_help_mail_address'=>'If you select "mail" for support method, please provide an e-mail address here.',
'cfg_explain_http_detect_language'=>'You can enable language detection of your visitors here. Their browsers do often send their preferred language.',
'cfg_explain_http_output_zlib'=>'Would you like to compress any outputs of the forum? This slightly raises server load and is disabled, if a visitor cannot handle it.',
'cfg_explain_http_rewrite_enable'=>'Should rewriting of links on the user frontend to a "search-engine friendly" format be enabled? This requires some manual work and depends on the webserver software. Please consult our FAQ for details.',
'cfg_explain_http_rewrite_server'=>'If you have enabled link rewriting, please provide the correct software setting to get proper commands for it.',
'cfg_explain_log_enable'=>'Enable logging? Messages will at least be put into database.',
'cfg_explain_log_forward'=>'Where would you like to store logging messages elsewhere? You can forward them to another facility to archive your logs. Please note that some have additional parameters - see "log_parameter".',
'cfg_explain_log_ip'=>'Should the IP-Address also be logged? If <u>disabled</u>, a dummy address is used.',
'cfg_explain_log_max_age'=>'How long should log entries be stored in database? A scheduled task will take care of it. Set to <u>0</u> for infinite time. This does not affect any forwarding by "log_engine"!',
'cfg_explain_log_parameter'=>'If the "log_forward" is "filexxx", then a full path to logfile is expected. "syslog" has no. <u>Disable</u> forwarding by choosing "none".',
'cfg_explain_log_statistic'=>'Log some statistical information on forum usage? Can be seen under "Log View" later on. This setting is independent from other logging - you can collect statistics even having general logging disabled.',
'cfg_explain_mail_from_mail'=>'What e-mail address should be used on sent mails?',
'cfg_explain_mail_from_name'=>'What name should be used on sent mails?',
'cfg_explain_mail_signing_class'=>'This defines the to be used class for mail signing. Please have a look in our documentation for setup.',
'cfg_explain_mail_signing_enable'=>'Should outgoing mails be digitally signed?',
'cfg_explain_mail_signing_param'=>'Parameters for the signing class.',
'cfg_explain_main_debug_verbose'=>'As long as <u>enabled</u> you will see detailed debug information on error reports ("Exception Handler"). Please be careful with it as anybody can see it, if they have an error themself.',
'cfg_explain_main_default_group'=>'A new fresh registered user will be assigned to this group.',
'cfg_explain_main_enable'=>'Is the forum running? <u>Disable</u> it for maintenance that nobody can perform actions.',
'cfg_explain_main_guest_uid'=>'What is the User-ID of the guest account?',
'cfg_explain_main_language'=>'Set the used language, if the user defined is not available.',
'cfg_explain_main_post_edit_limit'=>'How long are non-executive users are allowed to edit their postings? Value: <u>time</u>',
'cfg_explain_main_post_per_page'=>'Set the amount of postings to be seen on a single page.',
'cfg_explain_main_style'=>'What style should be default?',
'cfg_explain_main_tags_on_index'=>'How many "most used tags" should be listed on main overview?',
'cfg_explain_main_title'=>'The title of your forum.',
'cfg_explain_main_topic_navbar'=>'If <u>enabled</u>, an additional navigation bar is shown on every topic page. It contains links to next, previous and related topics. This can significantly increase load on your database. Use with caution!',
'cfg_explain_main_topic_per_page'=>'Set the amount of postings to be seen on main overview.',
'cfg_explain_param_action'=>'Name of GET-Parameter for "Action".',
'cfg_explain_param_ajax'=>'Filename of the "Asynchronous Request" (AJAX) proxy.',
'cfg_explain_param_file'=>'Filename of the main file.',
'cfg_explain_root_path'=>'Root Path of your forum. Must be a full path on your filesystem without trailing slash.',
'cfg_explain_root_uri'=>'Root URI of your forum. Must be a valid URI without trailing slash. If you establish a secured connection by using "https", it will be modified accordingly.',
'cfg_explain_rss_limit'=>'Set the limit of listed items in the "recent forum topics" RSS feed.',
'cfg_explain_rss_payload'=>'Include posting message on RSS feed?',
'cfg_explain_task_enable'=>'Enable running scheduled tasks?',
'cfg_explain_uri_css'=>'Full URI to Stylesheets without trailing slash.',
'cfg_explain_uri_gfx'=>'Full URI to Graphics without trailing slash.',
'cfg_explain_uri_js'=>'Full URI to Javascripts without trailing slash.',
'config_aux_auth'=>'These settings control the authentication for logged in users. To tighten the login session you should "bind" it to the user-provided data. In seldom cases this leads to logout, but you can disable the binding per-user in their profile settings.',
'config_aux_cache'=>'Enabling all caches is highly recommended to maximize performance and reduce server load. However occasionally you might see "old" content as a cache was not freshed up. In that case use the "Cache Manager" to force a rebuild.',
'config_aux_cookie'=>'It is only possible for users to transmit their authentication token by cookies. This is a little textfile stored in their browser. All cookies are encrypted and if you use SSL connections, you should set them so "SSL only".',
'config_aux_filter'=>'Postings from your users can be forwarded to a filtering system to detect unwanted entries. Several sources can be asked and you should have a look at our documentation for help.',
'config_aux_help'=>'These settings control the page behaviour, if your users click on "Help" in navigation panel.',
'config_aux_http'=>'Any explicit HTTP options can be set here.',
'config_aux_log'=>'It is advised to enable the logging of run actions in your forum. As soon as your privacy policies require it, you can disable storing the user IP-Address.',
'config_aux_mail'=>'Sender address for sent mails on registration or password requests.',
'config_aux_main'=>'Here we have the main settings for your forum. They control anything not suitable for the other categories.',
'config_aux_param'=>'Most users should leave these alone. Only experienced users can change them.',
'config_aux_root'=>'Both paths declare your forum root. Once on HTTP layer and the other on filesystem layer. They were set up during installation and usually need no change.',
'config_aux_rss'=>'Any user can sync to your forum topics by RSS feeds. These can be imported to news aggregator for fast reference without visiting the forum.',
'config_aux_task'=>'A scheduled task is regularly run after a few minutes and does some maintenance job in the background.',
'config_aux_uri'=>'You can set your full paths to any "resource" files here used by the forum. Most users can leave them alone.',
'config_aux__'=>'All settings of this forum on one page. Detailed info is available, if you limit your selection to one area.',
'config_seg_all'=>'All Settings',
'config_seg_auth'=>'Authentication Settings',
'config_seg_cache'=>'Cache Settings',
'config_seg_cookie'=>'Cookie Settings',
'config_seg_filter'=>'Message Filter Settings',
'config_seg_help'=>'Help Settings',
'config_seg_http'=>'HTTP Settings',
'config_seg_log'=>'Log Settings',
'config_seg_mail'=>'Mail Settings',
'config_seg_main'=>'Main Settings',
'config_seg_param'=>'Parameters: Main',
'config_seg_root'=>'Parameters: Root',
'config_seg_rss'=>'RSS Settings',
'config_seg_task'=>'Scheduled Task Settings',
'config_seg_uri'=>'Parameters: URI'
);
?>

==> larus_board-1.2.0.zip: larus_board-1.2.0/lb_private/lang/en/acpcfg.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'cfg_explain_auth_activate_limit'=>'How long can new accounts be unactivated until purged? Value: <u>time</u>.',
'cfg_explain_auth_bind_agent'=>'On login the current user agent is stored. If <u>enabled</u> the login gets invalid, as it changes during the session.',
'cfg_explain_auth_bind_ip'=>'On login the current IP-Address is stored. If <u>enabled</u> the login gets invalid, as it changes during the session.',
'cfg_explain_auth_max_faillogin'=>'How many fail logins are allowed until the possiblity of login is suspended for a few minutes?',
'cfg_explain_auth_max_lifetime'=>'How long does a login session remain valid? Value: <u>time</u>.',
'cfg_explain_auth_use_reauth'=>'Does an invalid login session may perform limited reauthentication attempts by giving its password?',
'cfg_explain_auth_use_tan'=>'Should changes submitted on forms be secured by a transaction number (TAN)?',
'cfg_explain_cache_acl'=>'Enable caching of access control rules?',
'cfg_explain_cache_config'=>'Enable caching of configuration?',
'cfg_explain_cache_main'=>'Enable caching of common data?',
'cfg_explain_cache_rss'=>'Enable caching of parsed RSS feeds?',
'cfg_explain_cache_topic'=>'Enable caching of topic data?',
'cfg_explain_cache_tpl'=>'Enable caching of compiled templates?',
'cfg_explain_cache_user'=>'Enable caching of user account data?',
'cfg_explain_cookie_autologin'=>'Name of the cookie for auto login.',
'cfg_explain_cookie_domain'=>'You can limit the domain where the cookies are allowed. Usually this is your full qualified domain name ("www.example.com").',
'cfg_explain_cookie_path'=>'You can limit them to specific paths on your domain name. Most compatible is "/".',
'cfg_explain_cookie_read_tracker'=>'Name of the cookie for "Last-Read-Post-Timestamp".',
'cfg_explain_cookie_session'=>'Name of the cookie for login session.',
'cfg_explain_cookie_ssl_only'=>'If <u>enabled</u>, the cookies are only transported over a secured (SSL) connection.',
'cfg_explain_filter_enable'=>'If you want to filter all postings for unwanted, please <u>enable</u> it here.',
'cfg_explain_filter_max_age_ip4'=>'How long are entries on IP-Addresses remain valid?',
'cfg_explain_filter_max_age_msg'=>'How long are entries on Postings remain valid?',
'cfg_explain_filter_max_age_uid'=>'How long are entries on User Accounts remain valid?',
'cfg_explain_filter_remote_proxy'=>'If any remote connections to other servers have to be done by a proxy, you should define it here. In most cases this field can be left blank.',
'cfg_explain_filter_sink_dnsbl_server'=>'Which nameservers should be queried for blacklisted addresses? You can set multiple by seperating them with a comma.',
'cfg_explain_filter_sink_local_class'=>'Any filter running on the local system can be included here. You should really consult our documentation for setup.',
'cfg_explain_filter_sink_local_param'=>'Any parameters to the filter class can be passed here.',
'cfg_explain_filter_size'=>'How many entries should be stored in our local database?',
'cfg_explain_filter_spam_action'=>'What should be done with marked postings? You can <u>accept</u> these anyway, <u>mark</u> makes them hidden or <u>reject</u> directly.',
'cfg_explain_filter_threshold'=>'When the local filter returns a score value, you can define here a threshold. Higher will be considered unwanted.',
'cfg_explain_help_class'=>'What type of support would you like to offer? <u>direct</u> means by submitting a topic and <u>mail</u> by e-mail.',
'cfg_explain_help_mail_address'=>'If you select "mail" for support method, please provide an e-mail address here.',
'cfg_explain_http_detect_language'=>'You can enable language detection of your visitors here. Their browsers do often send their preferred language.',
'cfg_explain_http_output_zlib'=>'Would you like to compress any outputs of the forum? This slightly raises server load and is disabled, if a visitor cannot handle it.',
'cfg_explain_http_proxy'=>'If the forum server has no direct internet connection, you can set a proxy here. Most people can left this field blank, otherwise give it in the format name:port like "name.of.proxy:8080".',
'cfg_explain_http_rewrite_enable'=>'Should rewriting of links on the user frontend to a "search-engine friendly" format be enabled? This requires some manual work and depends on the webserver software. Please consult our FAQ for details.',
'cfg_explain_http_rewrite_server'=>'If you have enabled link rewriting, please provide the correct software setting to get proper commands for it.',
'cfg_explain_log_enable'=>'Enable logging? Messages will at least be put into database.',
'cfg_explain_log_forward'=>'Where would you like to store logging messages elsewhere? You can forward them to another facility to archive your logs. Please note that some have additional parameters - see "log_parameter".',
'cfg_explain_log_ip'=>'Should the IP-Address also be logged? If <u>disabled</u>, a dummy address is used.',
'cfg_explain_log_max_age'=>'How long should log entries be stored in database? A scheduled task will take care of it. Set to <u>0</u> for infinite time. This does not affect any forwarding by "log_engine"!',
'cfg_explain_log_parameter'=>'If the "log_forward" is "filexxx", then a full path to logfile is expected. "syslog" has no. <u>Disable</u> forwarding by choosing "none".',
'cfg_explain_log_statistic'=>'Log some statistical information on forum usage? Can be seen under "Log View" later on. This setting is independent from other logging - you can collect statistics even having general logging disabled.',
'cfg_explain_mail_from_mail'=>'What e-mail address should be used on sent mails?',
'cfg_explain_mail_from_name'=>'What name should be used on sent mails?',
'cfg_explain_mail_signing_class'=>'This defines the to be used class for mail signing. Please have a look in our documentation for setup.',
'cfg_explain_mail_signing_enable'=>'Should outgoing mails be digitally signed?',
'cfg_explain_mail_signing_param'=>'Parameters for the signing class. Please have a look in our documentation for details.',
'cfg_explain_main_debug_verbose'=>'As long as <u>enabled</u> you will see detailed debug information on error reports ("Exception Handler"). Please be careful with it as anybody can see it, if they have an error themself.',
'cfg_explain_main_default_group'=>'A new fresh registered user will be assigned to this group.',
'cfg_explain_main_enable'=>'Is the forum running? <u>Disable</u> it for maintenance that nobody can perform actions.',
'cfg_explain_main_guest_uid'=>'What is the User-ID of the guest account?',
'cfg_explain_main_language'=>'Set the used language, if the user defined is not available.',
'cfg_explain_main_post_edit_limit'=>'How long are non-executive users are allowed to edit their postings? Value: <u>time</u>',
'cfg_explain_main_post_per_page'=>'Set the amount of postings to be seen on a single page.',
'cfg_explain_main_style'=>'What style should be default?',
'cfg_explain_main_tags_on_index'=>'How many "most used tags" should be listed on main overview?',
'cfg_explain_main_title'=>'The title of your forum.',
'cfg_explain_main_topic_navbar'=>'If <u>enabled</u>, an additional navigation bar is shown on every topic page. It contains links to next, previous and related topics. This can significantly increase load on your database. Use with caution!',
'cfg_explain_main_topic_per_page'=>'Set the amount of postings to be seen on main overview.',
'cfg_explain_param_action'=>'Name of GET-Parameter for "Action".',
'cfg_explain_param_ajax'=>'Filename of the "Asynchronous Request" (AJAX) proxy.',
'cfg_explain_param_file'=>'Filename of the main file.',
'cfg_explain_root_path'=>'Root Path of your forum. Must be a full path on your filesystem without trailing slash.',
'cfg_explain_root_uri'=>'Root URI of your forum. Must be a valid URI without trailing slash. If you establish a secured connection by using "https", it will be modified accordingly.',
'cfg_explain_rss_limit'=>'Set the limit of listed items in the "recent forum topics" RSS feed.',
'cfg_explain_rss_payload'=>'Include posting message on RSS feed?',
'cfg_explain_task_enable'=>'Enable running scheduled tasks?',
'cfg_explain_uri_css'=>'Full URI to Stylesheets without trailing slash.',
'cfg_explain_uri_gfx'=>'Full URI to Graphics without trailing slash.',
'cfg_explain_uri_js'=>'Full URI to Javascripts without trailing slash.',
'config_aux_auth'=>'These settings control the authentication for logged in users. To tighten the login session you should "bind" it to the user-provided data. In seldom cases this leads to logout, but you can disable the binding per-user in their profile settings.',
'config_aux_cache'=>'Enabling all caches is highly recommended to maximize performance and reduce server load. However occasionally you might see "old" content as a cache was not freshed up. In that case use the "Cache Manager" to force a rebuild.',
'config_aux_cookie'=>'It is only possible for users to transmit their authentication token by cookies. This is a little textfile stored in their browser. All cookies are encrypted and if you use SSL connections, you should set them so "SSL only".',
'config_aux_filter'=>'Postings from your users can be forwarded to a filtering system to detect unwanted entries. Several sources can be asked and you should have a look at our documentation for help.',
'config_aux_help'=>'These settings control the page behaviour, if your users click on "Help" in navigation panel.',
'config_aux_http'=>'Any explicit HTTP options can be set here.',
'config_aux_log'=>'It is advised to enable the logging of run actions in your forum. As soon as your privacy policies require it, you can disable storing the user IP-Address.',
'config_aux_mail'=>'Sender address for sent mails on registration or password requests.',
'config_aux_main'=>'Here we have the main settings for your forum. They control anything not suitable for the other categories.',
'config_aux_param'=>'Most users should leave these alone. Only experienced users can change them.',
'config_aux_root'=>'Both paths declare your forum root. Once on HTTP layer and the other on filesystem layer. They were set up during installation and usually need no change.',
'config_aux_rss'=>'Any user can sync to your forum topics by RSS feeds. These can be imported to news aggregator for fast reference without visiting the forum.',
'config_aux_task'=>'A scheduled task is regularly run after a few minutes and does some maintenance job in the background.',
'config_aux_uri'=>'You can set your full paths to any "resource" files here used by the forum. Most users can leave them alone.',
'config_aux__'=>'All settings of this forum on one page. Detailed info is available, if you limit your selection to one area.',
'config_seg_all'=>'All Settings',
'config_seg_auth'=>'Authentication Settings',
'config_seg_cache'=>'Cache Settings',
'config_seg_cookie'=>'Cookie Settings',
'config_seg_filter'=>'Message Filter Settings',
'config_seg_help'=>'Help Settings',
'config_seg_http'=>'HTTP Settings',
'config_seg_log'=>'Log Settings',
'config_seg_mail'=>'Mail Settings',
'config_seg_main'=>'Main Settings',
'config_seg_param'=>'Parameters: Main',
'config_seg_root'=>'Parameters: Root',
'config_seg_rss'=>'RSS Settings',
'config_seg_task'=>'Scheduled Task Settings',
'config_seg_uri'=>'Parameters: URI'
);
?>
